@@ -135,7 +135,7 @@ EXTERN char *ErrMsg[] =
     "OK",
     "Brakujący ']'",
     "Brakujący nawias",
-    "Zbyt skomplikowane wyrażenie - za dużo operatorów",
+    "Zbyt skomplikowane wyrażenie",
     "Zbyt skomplikowane wyrażenie - za dużo argumentów",
     "Brakujący ')'",
     "Nie zdefiniowana funkcja",
@@ -235,7 +235,10 @@ EXTERN char *ErrMsg[] =
     "No files matching *.rem",
     "String too long",
     "Time specified twice",
-    "Cannot specify DURATION without specifying AT"
+    "Cannot specify DURATION without specifying AT",
+    "Oczekiwana nazwa dnia tygodnia",
+    "Zduplikowana nazwa argumentu",
+    "Ocena wyrażeń jest wyłączona",
 };
 #endif /* MK_GLOBALS */
 
@@ -261,12 +264,10 @@ void Usage(void)
     fprintf(ErrFp, " -o     Ignoruj instrukcje ONCE\n");
     fprintf(ErrFp, " -t     Odpal wszystkie przyszłe przypomnienia niezależnie od delty\n");
     fprintf(ErrFp, " -h     Praca bezszmerowa\n");
-#ifdef HAVE_QUEUED
     fprintf(ErrFp, " -a     Nie odpalaj przyponień czasowych - kolejkuj je\n");
     fprintf(ErrFp, " -q     Nie kolejkuj przyponień czasowych\n");
     fprintf(ErrFp, " -f     Nie przechodź do pracy w tle\n");
     fprintf(ErrFp, " -z[n]  Pracuj jako demon, budząc się co n (5) minut\n");
-#endif
     fprintf(ErrFp, " -d...  Odpluskwianie: e=echo x=expr-eval t=trig v=dumpvars l=showline\n");
     fprintf(ErrFp, " -e     Komunikaty o błędach skieruj na stdout\n");
     fprintf(ErrFp, " -b[n]  Format czasu: 0=am/pm, 1=24godz., 2=żaden\n");
